@@ -24,11 +24,16 @@
 #include "gameitem.h"
 #include "gameview.h"
 #include "kmahjongglayout.h"
+#include "gamebackground.h"
+#include "gameremovedtiles.h"
+
 
 GameScene::GameScene(QObject * parent)
     : QGraphicsScene(parent)
     , m_pFirstSelectedItem(nullptr)
     , m_pSecondSelectedItem(nullptr)
+    , m_gameBackground(nullptr)
+    , m_gameRemovedTiles(nullptr)
 {
     initializeGameItemsArray();
 }
@@ -37,6 +42,22 @@ GameScene::~GameScene()
 {
 }
 
+void GameScene::clearGameItems()
+{
+    // Remove all GameItem objects and DON'T remove GameBackground object.
+    QList<QGraphicsItem*> items = QGraphicsScene::items();
+    for (int i = 0; i < items.size(); i++) {
+        GameItem *gameItem = dynamic_cast<GameItem*>(items.at(i));
+        if (gameItem != nullptr) {
+            QGraphicsScene::removeItem(gameItem);
+        }
+    }
+    initializeGameItemsArray();
+
+    m_pFirstSelectedItem = nullptr;
+    m_pSecondSelectedItem = nullptr;
+}
+
 void GameScene::clear()
 {
     QGraphicsScene::clear();
@@ -58,6 +79,28 @@ void GameScene::initializeGameItemsArray()
     }
 }
 
+void GameScene::setRemovedTilesItem(GameRemovedTiles * gameRemovedTiles)
+{
+    // If a removedtiles object already exist, delete it from scene
+    if (m_gameRemovedTiles != nullptr) {
+        QGraphicsScene::removeItem(m_gameRemovedTiles);
+    }
+
+    m_gameRemovedTiles = gameRemovedTiles;
+    QGraphicsScene::addItem(gameRemovedTiles);
+}
+
+void GameScene::setBackgroundItem(GameBackground * gameBackground)
+{
+    // If a background exist, delete it from scene
+    if (m_gameBackground != nullptr) {
+        QGraphicsScene::removeItem(m_gameBackground);
+    }
+
+    m_gameBackground = gameBackground;
+    QGraphicsScene::addItem(gameBackground);
+}
+
 void GameScene::addItem(GameItem * gameItem)
 {
     QGraphicsScene::addItem(gameItem);
@@ -139,7 +182,10 @@ QList<GameItem *> GameScene::items() const
     QList<GameItem *> tmpList;
 
     for (int i = 0; i < originalList.size(); ++i) {
-        tmpList.append(dynamic_cast<GameItem *>(originalList.at(i)));
+        GameItem * gameItem = dynamic_cast<GameItem *>(originalList.at(i));
+        if (gameItem != nullptr) {
+            tmpList.append(gameItem);
+        }
     }
 
     return tmpList;
@@ -202,15 +248,21 @@ void GameScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent * mouseEvent)
 void GameScene::mousePressEvent(QGraphicsSceneMouseEvent * mouseEvent)
 {
     // N.B. Event occurs when there is a click OR double-click with ANY button.
-    GameItem * gameItem = dynamic_cast<GameItem *>(itemAt(mouseEvent->scenePos().x(),
-                                                          mouseEvent->scenePos().y(), QTransform()));
+    GameItem * gameItem = dynamic_cast<GameItem *>(
+        itemAt(mouseEvent->scenePos().x(),
+        mouseEvent->scenePos().y(), QTransform())
+    );
 
     // An item was clicked.
     if (gameItem != nullptr) {
-        // If we click on a shadow of the actual item, we have to correct the clicking position, in
-        // order to simulate a transparent shadow.
+        // If we click on a shadow of the actual item, we have to correct the 
+        // clicking position, in order to simulate a transparent shadow.
         if (gameItem->isShadow(mouseEvent->scenePos() - gameItem->pos())) {
-            gameItem = dynamic_cast<GameItem *>(itemAt(mouseEvent->scenePos().x() + gameItem->getShadowDeltaX(), mouseEvent->scenePos().y() + gameItem->getShadowDeltaY(), QTransform()));
+            gameItem = dynamic_cast<GameItem *>(
+                itemAt(mouseEvent->scenePos().x() + gameItem->getShadowDeltaX(),
+                mouseEvent->scenePos().y() + gameItem->getShadowDeltaY(), 
+                QTransform())
+            );
         }
     }
 
