@@ -25,10 +25,6 @@
 
 // Qt
 #include <QDir>
-#include <QPainter>
-
-// KDE
-#include <KLocalizedString>
 
 // KMahjongg
 #include "gamedata.h"
@@ -113,9 +109,9 @@ void KMahjonggLayoutSelector::layoutChanged()
     }
 
     kcfg_Layout->setText(selLayout->path());
-    layoutAuthor->setText(selLayout->authorProperty("Author"));
-    layoutContact->setText(selLayout->authorProperty("AuthorEmail"));
-    layoutDescription->setText(selLayout->authorProperty("Description"));
+    layoutAuthor->setText(selLayout->authorProperty(QStringLiteral("Author")));
+    layoutContact->setText(selLayout->authorProperty(QStringLiteral("AuthorEmail")));
+    layoutDescription->setText(selLayout->authorProperty(QStringLiteral("Description")));
 
     //If settings for tiles/background have been applied, update our preview
     if (m_gameView->getTilesetPath() != Prefs::tileSet()) {
@@ -136,4 +132,5 @@ void KMahjonggLayoutSelector::layoutChanged()
 void KMahjonggLayoutSelector::useRandomLayoutToggled(bool active)
 {
     widgetNoRandom->setEnabled(!active);
+    m_gameView->setVisible(!active);
 }
